==> jc-1.4.0.tar.gz: java/util/MissingResourceException.h <==
// public class java.util.MissingResourceException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 648cd7d97906b7a9 java_util_MissingResourceException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_util_MissingResourceException_H_
#define _JC_java_util_MissingResourceException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_MissingResourceException$sub_refs	_jc_java_util_MissingResourceException$sub_refs;
typedef struct _jc_java_util_MissingResourceException$sub_nonrefs	_jc_java_util_MissingResourceException$sub_nonrefs;
typedef struct _jc_java_util_MissingResourceException$refs	_jc_java_util_MissingResourceException$refs;
typedef struct _jc_java_util_MissingResourceException$nonrefs	_jc_java_util_MissingResourceException$nonrefs;
typedef struct _jc_java_util_MissingResourceException$object	_jc_java_util_MissingResourceException$object;

typedef struct _jc_java_util_MissingResourceException$fields_struct	_jc_java_util_MissingResourceException$fields_struct;
typedef const struct _jc_java_util_MissingResourceException$vmethods	_jc_java_util_MissingResourceException$vmethods;
typedef const struct _jc_java_util_MissingResourceException$vtable	_jc_java_util_MissingResourceException$vtable;
typedef const struct _jc_java_util_MissingResourceException$vtype	_jc_java_util_MissingResourceException$vtype;

// Class fields structure
struct _jc_java_util_MissingResourceException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_MissingResourceException$fields_struct _jc_java_util_MissingResourceException$class_fields;

// Constructors
extern void _jc_java_util_MissingResourceException$method$_init$ab068ddc672b930e(_jc_env *, struct _jc_java_util_MissingResourceException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_util_MissingResourceException$method$getClassName$333433582f896913(_jc_env *, struct _jc_java_util_MissingResourceException$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_MissingResourceException$method$getKey$34fe8b840403bb48(_jc_env *, struct _jc_java_util_MissingResourceException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_MissingResourceException$method_info$getClassName$333433582f896913;
extern _jc_method _jc_java_util_MissingResourceException$method_info$getKey$34fe8b840403bb48;

// Virtual methods structure
struct _jc_java_util_MissingResourceException$vmethods {
	struct _jc_java_lang_String$object	*(*getClassName$333433582f896913)(_jc_env *, struct _jc_java_util_MissingResourceException$object *);
	struct _jc_java_lang_String$object	*(*getKey$34fe8b840403bb48)(_jc_env *, struct _jc_java_util_MissingResourceException$object *);
};

// Vtable
struct _jc_java_util_MissingResourceException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_util_MissingResourceException$vmethods	java_util_MissingResourceException;
};

// Vtype
struct _jc_java_util_MissingResourceException$vtype {
	_jc_type			type;
	_jc_java_util_MissingResourceException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_MissingResourceException$sub_refs {
	struct _jc_java_lang_String$object	*className;
	struct _jc_java_lang_String$object	*key;
};

// Reference instance fields (object)
struct _jc_java_util_MissingResourceException$refs {
    _jc_java_util_MissingResourceException$sub_refs	java_util_MissingResourceException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_MissingResourceException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_MissingResourceException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_util_MissingResourceException$sub_nonrefs	java_util_MissingResourceException;
};

// Object instance structure
struct _jc_java_util_MissingResourceException$object {
	_jc_java_util_MissingResourceException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_MissingResourceException$vtype	*vtype;
	_jc_java_util_MissingResourceException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_MissingResourceException$vtype _jc_java_util_MissingResourceException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_MissingResourceException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_MissingResourceException$class_object;

#endif	/* _JC_java_util_MissingResourceException_H_ */

==> jc-1.4.6.tar.gz: java/util/MissingResourceException.h <==
// public class java.util.MissingResourceException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 648cd7d97906b7a9 java_util_MissingResourceException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_util_MissingResourceException_H_
#define _JC_java_util_MissingResourceException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_MissingResourceException$sub_refs	_jc_java_util_MissingResourceException$sub_refs;
typedef struct _jc_java_util_MissingResourceException$sub_nonrefs	_jc_java_util_MissingResourceException$sub_nonrefs;
typedef struct _jc_java_util_MissingResourceException$refs	_jc_java_util_MissingResourceException$refs;
typedef struct _jc_java_util_MissingResourceException$nonrefs	_jc_java_util_MissingResourceException$nonrefs;
typedef struct _jc_java_util_MissingResourceException$object	_jc_java_util_MissingResourceException$object;

typedef struct _jc_java_util_MissingResourceException$fields_struct	_jc_java_util_MissingResourceException$fields_struct;
typedef const struct _jc_java_util_MissingResourceException$vmethods	_jc_java_util_MissingResourceException$vmethods;
typedef const struct _jc_java_util_MissingResourceException$vtable	_jc_java_util_MissingResourceException$vtable;
typedef const struct _jc_java_util_MissingResourceException$vtype	_jc_java_util_MissingResourceException$vtype;

// Class fields structure
struct _jc_java_util_MissingResourceException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_MissingResourceException$fields_struct _jc_java_util_MissingResourceException$class_fields;

// Constructors
extern void _jc_java_util_MissingResourceException$method$_init$ab068ddc672b930e(_jc_env *, struct _jc_java_util_MissingResourceException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_util_MissingResourceException$method$getClassName$333433582f896913(_jc_env *, struct _jc_java_util_MissingResourceException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_MissingResourceException$method$getKey$34fe8b840403bb48(_jc_env *, struct _jc_java_util_MissingResourceException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_MissingResourceException$method_info$getClassName$333433582f896913;
extern _jc_method _jc_java_util_MissingResourceException$method_info$getKey$34fe8b840403bb48;

// Virtual methods structure
struct _jc_java_util_MissingResourceException$vmethods {
	struct _jc_java_lang_String$object	*(*getClassName$333433582f896913)(_jc_env *, struct _jc_java_util_MissingResourceException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getKey$34fe8b840403bb48)(_jc_env *, struct _jc_java_util_MissingResourceException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_MissingResourceException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_util_MissingResourceException$vmethods	java_util_MissingResourceException;
};

// Vtype
struct _jc_java_util_MissingResourceException$vtype {
	_jc_type			type;
	_jc_java_util_MissingResourceException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_MissingResourceException$sub_refs {
	struct _jc_java_lang_String$object	*className;
	struct _jc_java_lang_String$object	*key;
};

// Reference instance fields (object)
struct _jc_java_util_MissingResourceException$refs {
    _jc_java_util_MissingResourceException$sub_refs	java_util_MissingResourceException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_MissingResourceException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_MissingResourceException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_util_MissingResourceException$sub_nonrefs	java_util_MissingResourceException;
};

// Object instance structure
struct _jc_java_util_MissingResourceException$object {
	_jc_java_util_MissingResourceException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_MissingResourceException$vtype	*vtype;
	_jc_java_util_MissingResourceException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_MissingResourceException$vtype _jc_java_util_MissingResourceException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_MissingResourceException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_MissingResourceException$class_object;

#endif	/* _JC_java_util_MissingResourceException_H_ */
